@@ -1,4 +1,4 @@
-# $Id: RFC1738.pm,v 2.100 2003/02/10 21:03:54 abigail Exp $
+# $Id: RFC1738.pm,v 2.102 2003/02/21 14:47:48 abigail Exp $
 
 package Regexp::Common::URI::RFC1738;
 
@@ -12,18 +12,21 @@ use vars qw /$VERSION @EXPORT @EXPORT_OK %EXPORT_TAGS @ISA/;
 use Exporter ();
 @ISA = qw /Exporter/;
 
-($VERSION) = q $Revision: 2.100 $ =~ /[\d.]+/g;
+($VERSION) = q $Revision: 2.102 $ =~ /[\d.]+/g;
 
 my %vars;
 
 BEGIN {
     $vars {low}     = [qw /$digit $digits $hialpha $lowalpha $alpha $alphadigit
                            $safe $extra $national $punctuation $unreserved
-                           $reserved $uchar $uchars $xchar $xchars $hex
-                           $escaped/];
+                           $unreserved_range $reserved $uchar $uchars $xchar
+                           $xchars $hex $escaped/];
+
     $vars {connect} = [qw /$port $hostnumber $toplabel $domainlabel $hostname
                            $host $hostport $user $password $login/];
-    $vars {parts}   = [qw /$fsegment $fpath/];
+
+    $vars {parts}   = [qw /$fsegment $fpath $group $article $grouppart
+                           $database $wtype $wpath/];
 }
 
 use vars map {@$_} values %vars;
@@ -45,14 +48,15 @@ $safe              =  '[-$_.+]';
 $extra             =  "[!*'(),]";
 $national          =  '[][{}|\\^~`]';
 $punctuation       =  '[<>#%"]';
-$unreserved        =  "[a-zA-Z0-9\\-\$_.+!*'(),]"; # alphadigit | safe | extra
+$unreserved_range  = q [-a-zA-Z0-9$_.+!*'(),];  # alphadigit | safe | extra
+$unreserved        =  "[$unreserved_range]";
 $reserved          =  '[;/?:@&=]';
 $hex               =  '[a-fA-F0-9]';
 $escaped           =  "(?:%$hex$hex)";
 $uchar             =  "(?:$unreserved|$escaped)";
 $uchars            =  "(?:(?:$unreserved+|$escaped)*)";
-$xchar             =  "(?:[a-zA-Z0-9\\-\$_.+!*'(),;/?:\@&=]|$escaped)";
-$xchars            =  "(?:(?:[a-zA-Z0-9\\-\$_.+!*'(),;/?:\@&=]+|$escaped)*)";
+$xchar             =  "(?:[$unreserved_range;/?:\@&=]|$escaped)";
+$xchars            =  "(?:(?:[$unreserved_range;/?:\@&=]+|$escaped)*)";
 
 # Connection related stuff.
 $port              =  "(?:$digits)";
@@ -63,14 +67,29 @@ $hostname          =  "(?:(?:$domainlabel\[.])*$toplabel)";
 $host              =  "(?:$hostname|$hostnumber)";
 $hostport          =  "(?:$host(?::$port)?)";
 
-$user              =  "(?:(?:[a-zA-Z0-9\\-\$_.+!*'(),;?&=]+|$escaped)*)";
-$password          =  "(?:(?:[a-zA-Z0-9\\-\$_.+!*'(),;?&=]+|$escaped)*)";
+$user              =  "(?:(?:[$unreserved_range;?&=]+|$escaped)*)";
+$password          =  "(?:(?:[$unreserved_range;?&=]+|$escaped)*)";
 $login             =  "(?:(?:$user(?::$password)?\@)?$hostport)";
 
 # Parts (might require more if we add more URIs).
-$fsegment          =  "(?:(?:[a-zA-Z0-9\\-\$_.+!*'(),:\@&=]+|$escaped)*)";
+
+# FTP/file
+$fsegment          =  "(?:(?:[$unreserved_range:\@&=]+|$escaped)*)";
 $fpath             =  "(?:$fsegment(?:/$fsegment)*)";
 
+# NNTP/news.
+$group             =  "(?:$alpha\[-A-Za-z0-9.+_]*)";
+$article           =  "(?:(?:[$unreserved_range;/?:&=]+|$escaped)+" .
+                      '@' . "$host)";
+$grouppart         =  "(?:[*]|$article|$group)"; # It's important that
+                                                 # $article goes before
+                                                 # $group.
+
+# WAIS.
+$database          =  $uchars;
+$wtype             =  $uchars;
+$wpath             =  $uchars;
+
 
 1;
 
@@ -106,6 +125,12 @@ Locators (URL)>. December 1994.
 =head1 HISTORY
 
  $Log: RFC1738.pm,v $
+ Revision 2.102  2003/02/21 14:47:48  abigail
+ Added  and WAIS related variables
+
+ Revision 2.101  2003/02/11 11:14:50  abigail
+ Fixed $grouppart
+
  Revision 2.100  2003/02/10 21:03:54  abigail
  Definitions of RFC 1738
 
